phoneclientserver/phoneclient/Inc/UssdWrapper/Ussd_Ext/CPhCltUssdImp.h
changeset 15 d7fc66ccd6fb
parent 13 e32024264ebb
child 27 7eb70891911c
--- a/phoneclientserver/phoneclient/Inc/UssdWrapper/Ussd_Ext/CPhCltUssdImp.h	Fri Apr 16 15:31:58 2010 +0300
+++ b/phoneclientserver/phoneclient/Inc/UssdWrapper/Ussd_Ext/CPhCltUssdImp.h	Mon May 03 13:01:45 2010 +0300
@@ -171,8 +171,8 @@
         // Called when send completes.
         void HandleSendEventL( const TInt aError );
 
-        // Called when the user cancel the wait dialog.
-        void GlobalWaitNoteDismissedL( TInt aButtonId );
+        // Hidden when the user cancel the wait dialog.
+        void GlobalWaitNoteHidden();